==> 0.0.7.tar.gz: example/lib/page_settings.dart <==
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class SettingsPage extends StatefulWidget {
  @override
  _SettingsPageState createState() => _SettingsPageState();
}

class _SettingsPageState extends State<SettingsPage> {
  disablePopupPresentation() {
    Netmera.disablePopupPresentation();
  }

  enablePopupPresentation() {
    Netmera.enablePopupPresentation();
  }

  requestPermissionsForLocation() {
    Netmera.requestPermissionsForLocation();
  }

  setNetmeraMaxActiveRegions() {
    Netmera.setNetmeraMaxActiveRegions(10);
  }

  turnOffSendingEventAndUserUpdate() {
    Netmera.turnOffSendingEventAndUserUpdate(false);
  }

  toggleWebViewProgressBarVisibility() {
    Netmera.toggleWebViewProgressBarVisibility(true);
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        RaisedButton(
          child: Text('Disable Popup Presentation'),
          onPressed: disablePopupPresentation,
        ),
        RaisedButton(child: Text('Enable Popup Presentation'), onPressed: enablePopupPresentation),
        RaisedButton(
          child: Text('Request Permission For Location'),
          onPressed: requestPermissionsForLocation,
        ),
        RaisedButton(
          child: Text('Set Netmera Max Active Regions'),
          onPressed: setNetmeraMaxActiveRegions,
        ),
        RaisedButton(
          child: Text('Turn Off Sending Event And User Update'),
          onPressed: turnOffSendingEventAndUserUpdate,
        ),
        RaisedButton(
          child: Text('Toggle Web View Progress Bar Visibility (True)'),
          onPressed: toggleWebViewProgressBarVisibility,
        ),
      ],
    );
  }
}

==> 1.0.4.tar.gz: example/lib/page_settings.dart <==
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class SettingsPage extends StatefulWidget {
  @override
  _SettingsPageState createState() => _SettingsPageState();
}

class _SettingsPageState extends State<SettingsPage> {
  disablePopupPresentation() {
    Netmera.disablePopupPresentation();
  }

  enablePopupPresentation() {
    Netmera.enablePopupPresentation();
  }

  requestPermissionsForLocation() {
    Netmera.requestPermissionsForLocation();
  }

  setNetmeraMaxActiveRegions() {
    Netmera.setNetmeraMaxActiveRegions(10);
  }

  turnOffSendingEventAndUserUpdate() {
    Netmera.turnOffSendingEventAndUserUpdate(false);
  }

  toggleWebViewProgressBarVisibility() {
    Netmera.toggleWebViewProgressBarVisibility(true);
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        RaisedButton(
          child: Text('Disable Popup Presentation'),
          onPressed: disablePopupPresentation,
        ),
        RaisedButton(
            child: Text('Enable Popup Presentation'),
            onPressed: enablePopupPresentation),
        RaisedButton(
          child: Text('Request Permission For Location'),
          onPressed: requestPermissionsForLocation,
        ),
        RaisedButton(
          child: Text('Set Netmera Max Active Regions'),
          onPressed: setNetmeraMaxActiveRegions,
        ),
        RaisedButton(
          child: Text('Turn Off Sending Event And User Update'),
          onPressed: turnOffSendingEventAndUserUpdate,
        ),
        RaisedButton(
          child: Text('Toggle Web View Progress Bar Visibility (True)'),
          onPressed: toggleWebViewProgressBarVisibility,
        ),
      ],
    );
  }
}
